@@ -1,8 +1,10 @@
 /*
     iom_conf.h -- generic I/O multiplexer config
-    Copyright (C) 2003, 2004 Marc Lehmann <pcg@goof.com>
+    Copyright (C) 2003, 2004 Marc Lehmann <gvpe@schmorp.de>
  
-    This program is free software; you can redistribute it and/or modify
+    This file is part of GVPE.
+
+    GVPE is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
@@ -13,12 +15,12 @@
     GNU General Public License for more details.
  
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
+    along with gvpe; if not, write to the Free Software
     Foundation, Inc. 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef VPE_IOM_CONF_H__
-#define VPE_IOM_CONF_H__
+#ifndef GVPE_IOM_CONF_H__
+#define GVPE_IOM_CONF_H__
 
 #include "config.h"
 
